==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust):
            GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust =
            GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust(
    public val acms: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustAcm>,
    public val files: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustFile>,
    public val sds: List<GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustSd>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust): GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust =
            GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrust(
                acms = javaType.acms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }),
                files = javaType.files().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustFile.Companion.toKotlin(args0)
                    })
                }),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendDefaultClientPolicyTlValidationTrustSd.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
